@@ -1,16 +1,17 @@
-extern crate core;
-
+pub use error::RrError;
 pub use hash::*;
 pub use list::*;
-pub use redis_rocksdb::redis_rocksdb::*;
 pub use set::*;
 pub use sorted_set::*;
 pub use types::*;
 
+pub use crate::redis_rocksdb::*;
+
 mod list;
 mod set;
 mod sorted_set;
 mod hash;
 mod types;
-pub mod redis_rocksdb;
+mod redis_rocksdb;
+mod error;
 
