@@ -1,4 +1,6 @@
-pub mod redis_rocksdb;
+pub use self::redis_rocksdb::RedisRocksdb;
+
+mod redis_rocksdb;
 mod list_impl;
 mod quick_list;
 mod zip_list;
